from typing import Dict, Optional, Type

from fck.cktype.cktypeinterface import CKTYPEINTERFACE as CKTYPEINTERFACE

from .crc32 import CRC32
from .md5 import MD5
from .sha1 import SHA1
from .sha224 import SHA224
from .sha256 import SHA256
from .sha512 import SHA512

CKTYPES: Dict[str, Type[CRC32 | MD5 | SHA1 | SHA224 | SHA256 | SHA512]] = {
    "CRC32": (CRC32),
    "MD5": (MD5),
    "SHA1": (SHA1),
    "SHA224": (SHA224),
    "SHA256": (SHA256),
    "SHA512": (SHA512),
}


def resolve(fname: str, esum: Optional[str] = None, cstype: str = ""):
    """
    Checks fname input for checksum patterns and returns first match.
    Can be overridden with cstype.
    If neither is applicable it defaults to CRC32.
    """
    cstype = cstype.upper()
    if cstype != "":
        if cstype in CKTYPES:
            if esum is None and (match := CKTYPES[cstype].REGEX.search(fname)):
                esum = match.group(0)
            return CKTYPES[cstype](), esum
        raise ValueError(f"Unknown checksum type: {cstype}")

    for csclass in CKTYPES.values():
        if match := csclass.REGEX.search(fname):
            if esum is None:
                esum = match.group(0)
            return csclass(), esum

    return CRC32(), esum
