from typing import List
from re import compile, Pattern
from hashlib import sha224


class SHA224(object):
    NAME: str = "SHA224"
    EXT: List[str] = [".sha224"]
    SYNTAX: List[Pattern] = [compile(r"^;*$"), compile(r"^.* [0-9a-fA-F]{56}$")]
    REGEX: Pattern = compile(r"[0-9a-fA-F]{56}")
    NULL: str = "D14A028C2A3A2BC9476102BB288234C415A2B01F828EA62AC5B3E42F"

    def __init__(self):
        self.cksum = sha224(usedforsecurity=False)

    def gensum(self, data: bytes):
        self.cksum.update(data)

    def reset(self):
        self.__init__()

    def format(self, fpath) -> str:
        return " ".join([self.__repr__(), fpath])

    def __repr__(self) -> str:
        return self.cksum.hexdigest().upper()
