from typing import List
from re import compile, Pattern
from hashlib import sha256


class SHA256(object):
    NAME: str = "SHA256"
    EXT: List[str] = [".sha256"]
    SYNTAX: List[Pattern] = [compile(r"^;*$"), compile(r"^.* [0-9a-fA-F]{64}$")]
    REGEX: Pattern = compile(r"[0-9a-fA-F]{64}")
    NULL: str = "E3B0C44298FC1C149AFBF4C8996FB92427AE41E4649B934CA495991B7852B855"

    def __init__(self):
        self.cksum = sha256(usedforsecurity=False)

    def gensum(self, data: bytes):
        self.cksum.update(data)

    def reset(self):
        self.__init__()

    def format(self, fpath) -> str:
        return " ".join([self.__repr__(), fpath])

    def __repr__(self) -> str:
        return self.cksum.hexdigest().upper()
