from typing import List
from re import compile, Pattern
from hashlib import sha384


class SHA384(object):
    NAME: str = "SHA384"
    EXT: List[str] = [".sha384"]
    SYNTAX: List[Pattern] = [compile(r"^;*$"), compile(r"^.* [0-9a-fA-F]{96}$")]
    REGEX: Pattern = compile(r"[0-9a-fA-F]{96}")
    NULL: str = "38B060A751AC96384CD9327EB1B1E36A21FDB71114BE07434C0CC7BF63F6E1DA274EDEBFE76F65FBD51AD2F14898B95B"

    def __init__(self):
        self.cksum = sha384(usedforsecurity=False)

    def gensum(self, data: bytes):
        self.cksum.update(data)

    def reset(self):
        self.__init__()

    def format(self, fpath) -> str:
        return " ".join([self.__repr__(), fpath])

    def __repr__(self) -> str:
        return self.cksum.hexdigest().upper()
