from typing import List
from re import compile, Pattern
from hashlib import sha512


class SHA512(object):
    NAME: str = "SHA512"
    EXT: List[str] = [".sha512"]
    SYNTAX: List[Pattern] = [compile(r"^;*$"), compile(r"^.* [0-9a-fA-F]{128}$")]
    REGEX: Pattern = compile(r"[0-9a-fA-F]{128}")
    NULL: str = "CF83E1357EEFB8BDF1542850D66D8007D620E4050B5715DC83F4A921D36CE9CE47D0D13C5D85F2B0FF8318D2877EEC2F63B931BD47417A81A538327AF927DA3E"

    def __init__(self):
        self.cksum = sha512(usedforsecurity=False)

    def gensum(self, data: bytes):
        self.cksum.update(data)

    def reset(self):
        self.__init__()

    def format(self, fpath) -> str:
        return " ".join([self.__repr__(), fpath])

    def __repr__(self) -> str:
        return self.cksum.hexdigest().upper()
